"""字符串工具类 (StringUtils)"""

class StringUtils:
    """提供常用的字符串处理工具方法"""
    
    @staticmethod
    def is_empty(text: str) -> bool:
        """检查字符串是否为空（None、空字符串或只包含空白字符）"""
        return text is None or not text.strip()
    
    @staticmethod
    def to_camel_case(text: str) -> str:
        """将下划线分隔的字符串转换为驼峰命名法"""
        if StringUtils.is_empty(text):
            return text
        
        parts = text.split('_')
        return parts[0].lower() + ''.join(part.capitalize() for part in parts[1:])
    
    @staticmethod
    def to_snake_case(text: str) -> str:
        """将驼峰命名的字符串转换为下划线分隔的格式"""
        if StringUtils.is_empty(text):
            return text
        
        result = []
        for i, char in enumerate(text):
            if i > 0 and char.isupper():
                result.append('_')
            result.append(char.lower())
        return ''.join(result)
    
    @staticmethod
    def truncate(text: str, max_length: int, suffix: str = '...') -> str:
        """截断字符串到指定长度，如果超长则添加后缀"""
        if StringUtils.is_empty(text) or len(text) <= max_length:
            return text
        
        return text[:max_length - len(suffix)] + suffix
    
    @staticmethod
    def repeat(text: str, times: int) -> str:
        """重复字符串指定次数"""
        if text is None:
            return ''
        return text * times
    
    @staticmethod
    def count_occurrences(text: str, substring: str) -> int:
        """计算子字符串在文本中出现的次数"""
        if StringUtils.is_empty(text) or StringUtils.is_empty(substring):
            return 0
        return text.count(substring)


"""简单实用工具库 (simple_utils)"""

__version__ = "0.1.0"
__author__ = "Your Name"
__email__ = "your.email@example.com"

from .string_utils import StringUtils
from .number_utils import NumberUtils

__all__ = ['StringUtils', 'NumberUtils']


"""数字工具类 (NumberUtils)"""

class NumberUtils:
    """提供常用的数字处理工具方法"""
    
    @staticmethod
    def is_even(number: int) -> bool:
        """检查一个数是否为偶数"""
        return number % 2 == 0
    
    @staticmethod
    def is_odd(number: int) -> bool:
        """检查一个数是否为奇数"""
        return number % 2 != 0
    
    @staticmethod
    def is_prime(number: int) -> bool:
        """检查一个数是否为质数"""
        if number <= 1:
            return False
        if number <= 3:
            return True
        if number % 2 == 0 or number % 3 == 0:
            return False
        i = 5
        while i * i <= number:
            if number % i == 0 or number % (i + 2) == 0:
                return False
            i += 6
        return True
    
    @staticmethod
    def to_rounded(number: float, decimals: int = 0) -> float:
        """将数字四舍五入到指定小数位"""
        return round(number, decimals)
    
    @staticmethod
    def clamp(value: float, min_value: float, max_value: float) -> float:
        """将值限制在指定的范围内"""
        return max(min_value, min(max_value, value))
    
    @staticmethod
    def average(numbers: list) -> float:
        """计算列表中数字的平均值"""
        if not numbers:
            raise ValueError("Cannot calculate average of an empty list")
        return sum(numbers) / len(numbers)
    
    @staticmethod
    def sum_digits(number: int) -> int:
        """计算一个整数各位数字之和"""
        return sum(int(digit) for digit in str(abs(number)))
    
    @staticmethod
    def format_number(number: float, decimal_places: int = 2) -> str:
        """格式化数字为字符串，保留指定的小数位"""
        format_string = f"%.{decimal_places}f"
        return format_string % number